package com.rf.conversion.user.rest;

import com.alibaba.fastjson.JSONObject;
import com.rf.conversion.base.rest.BaseController;
import com.rf.conversion.user.dao.model.UserConversionEntity;
import com.rf.conversion.user.service.UserConversionService;
import com.rf.conversion.utils.DateUtil;
import com.rf.conversion.utils.Result;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.*;


/**
 * @Description: 用户转换文件相关接口
 * @Author: zsy
 * @Date: 2024/12/4
 */
@RestController
@RequestMapping("/userConversion")
@Api(tags = "用户转换文件相关接口")
@Slf4j
public class UserConversionController extends BaseController {

    @Autowired
    private UserConversionService userConversionService;

    @PostMapping("/saveConversion")
    @ApiOperation(value = "保存转换文件记录", notes = "参数：json对象；userId：用户ID；taskId：任务ID；type：类型；uploadName：上传文件名称；handleName：处理后文件名称")
    public Result saveConversion(@RequestBody String json) {
        UserConversionEntity userConversionEntity = JSONObject.parseObject(json, UserConversionEntity.class);
        userConversionEntity.setCreateTime(DateUtil.getNowTime());
        userConversionEntity.setUpdateTime(DateUtil.getNowTime());
        userConversionEntity = this.userConversionService.save(userConversionEntity);
        return success(userConversionEntity);
    }

    @GetMapping("/findUserConversionList")
    @ApiOperation(value = "转换文件记录列表查询", notes = "参数包括：beginNum:页码，pageSize：每页条数，userId：用户ID")
    public Result findUserConversionList(String userId, int beginNum, int pageSize) {
        Page<UserConversionEntity> userConversionEntities = this.userConversionService.findUserConversionList(userId, beginNum, pageSize);
        return success(userConversionEntities);
    }

}
